{
 "metadata": {
  "name": "",
  "signature": "sha256:37de54f6c61957049dd632042c223a4a1674d548c2830d553168f6ea9e5f8295"
 },
 "nbformat": 3,
 "nbformat_minor": 0,
 "worksheets": [
  {
   "cells": [
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "%matplotlib inline\n",
      "import numpy as np\n",
      "import scipy.linalg\n",
      "import matplotlib.pyplot as plt, mpld3\n",
      "plt.rcParams['figure.figsize'] = 12, 9\n",
      "mpld3.enable_notebook()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 1
    },
    {
     "cell_type": "heading",
     "level": 1,
     "metadata": {},
     "source": [
      "Adiabatic Evolution of a Single Spin in External Magnetic Field"
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Pauli matrices:"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "sigma_x = np.array([[0, 1], [1,0]])\n",
      "sigma_y = np.array([[0, 1j], [-1j, 0]])\n",
      "sigma_z = np.array([[1, 0], [0, -1]])"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 2
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Parameter-dependent Hamiltonian:"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def H(s):\n",
      "    return -(np.cos(np.pi*0.5*s)*sigma_z + np.sin(np.pi*0.5*s)*sigma_x)\n",
      "\n",
      "assert np.allclose(H(0), -sigma_z)\n",
      "assert np.allclose(H(1), -sigma_x)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 3
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Overlap with ground state:"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def overlap(s, psi):\n",
      "    Es, v = np.linalg.eigh(H(s))\n",
      "    ground_state = v[:, 0] if Es[0] <= Es[1] else v[:, 1]\n",
      "    return np.abs(np.dot(ground_state, psi))**2\n",
      "\n",
      "assert np.isclose(overlap(0, [np.sqrt(0.3), np.sqrt(0.7)]), 0.3)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 4
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Various time evolution methods:"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def euler(psi, s, dt):\n",
      "    psi = psi - 1j*dt*np.dot(H(s), psi)\n",
      "    return psi / np.linalg.norm(psi)\n",
      "\n",
      "def unitary(psi, s, dt):\n",
      "    psi = np.dot(np.eye(2) - 0.5j*dt*H(s), psi)\n",
      "    return np.linalg.solve(np.eye(2) + 0.5j*dt*H(s), psi)\n",
      "\n",
      "def expm(psi, s, dt):\n",
      "      U = scipy.linalg.expm(-1j*dt*H(s))\n",
      "      return np.dot(U, psi)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 5
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Adiabatic evolution from initial ground state:"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def adiabatic(t_max, t_steps=100, method=expm):\n",
      "    psi = np.array([1, 0])\n",
      "    ts, dt = np.linspace(0, t_max, t_steps, retstep=True)\n",
      "    overlaps = []\n",
      "    for t in ts:\n",
      "        s = t / float(t_max)\n",
      "        psi = method(psi, s, dt)\n",
      "        overlaps.append(overlap(s, psi))\n",
      "    return ts, overlaps\n",
      "\n",
      "[adiabatic(t_max)[1][-1] for t_max in [1, 10]]"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "metadata": {},
       "output_type": "pyout",
       "prompt_number": 6,
       "text": [
        "[0.65162718207809145, 0.9980047287715802]"
       ]
      }
     ],
     "prompt_number": 6
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Compare the different methods (with different $t_{\\max}$es):"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "t_maxes = np.arange(1, 20, 0.5)\n",
      "\n",
      "plt.title('overlap with final ground state')\n",
      "plt.xlabel('t_max')\n",
      "plt.ylabel('overlap')\n",
      "plt.grid(color='lightgray', alpha=0.7)\n",
      "for method in [euler, unitary, expm]:\n",
      "    plt.plot(t_maxes, [adiabatic(t_max, method=method)[1][-1] for t_max in t_maxes], label=method.__name__)\n",
      "plt.legend()\n",
      "plt.show()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "\n",
        "\n",
        "<style>\n",
        "\n",
        "</style>\n",
        "\n",
        "<div id=\"fig_el5684169326744738489165\"></div>\n",
        "<script>\n",
        "function mpld3_load_lib(url, callback){\n",
        "  var s = document.createElement('script');\n",
        "  s.src = url;\n",
        "  s.async = true;\n",
        "  s.onreadystatechange = s.onload = callback;\n",
        "  s.onerror = function(){console.warn(\"failed to load library \" + url);};\n",
        "  document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
        "}\n",
        "\n",
        "if(typeof(mpld3) !== \"undefined\" && mpld3._mpld3IsLoaded){\n",
        "   // already loaded: just create the figure\n",
        "   !function(mpld3){\n",
        "       \n",
        "       mpld3.draw_figure(\"fig_el5684169326744738489165\", {\"axes\": [{\"xlim\": [0.0, 20.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"t_max\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el5684171135720\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"overlap\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.044942876344086002, 0.5], \"rotation\": -90.0, \"id\": \"el5684171126288\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"overlap with final ground state\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el5684171199680\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"euler\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.92151797715053785, 0.96057347670250903], \"rotation\": -0.0, \"id\": \"el5684171270776\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"unitary\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.92151797715053785, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el5684171272792\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"expm\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.92151797715053785, 0.89008363201911578], \"rotation\": -0.0, \"id\": \"el5684173421232\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 20.0], \"ylim\": [0.65000000000000002, 1.0], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el5684171245408\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"color\": \"#D3D3D3\", \"alpha\": 0.7, \"dasharray\": \"2,2\", \"gridOn\": true}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 5, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"color\": \"#D3D3D3\", \"alpha\": 0.7, \"dasharray\": \"2,2\", \"gridOn\": true}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el5684171170896\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el5684169247800\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el5684171124552\"}, {\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el5684171271504\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el5684171273576\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el5684173422016\"}], \"markers\": [], \"id\": \"el5684169249088\", \"ydomain\": [0.65000000000000002, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data02\": [[0.8767151097670253, 0.968936678614098, 0.9336917562724016, 0.8984468339307048], [0.9018047155017923, 0.968936678614098, 0.9336917562724016, 0.8984468339307048]], \"data03\": [[0.8641703068996417, 0.8751493428912785], [0.9910394265232977, 0.8751493428912785], [0.9910394265232977, 0.9880525686977301], [0.8641703068996417, 0.9880525686977301], [0.8641703068996417, 0.8751493428912785]], \"data01\": [[1.0, 0.6516182770347534, 0.6516249557032787, 0.6516271820780914], [1.5, 0.7879887868989918, 0.788011854466613, 0.7880195445853719], [2.0, 0.9061899948626114, 0.9062297889384199, 0.9062430550621546], [2.5, 0.9776795613587497, 0.9777155361441456, 0.9777275251036297], [3.0, 0.99988999298591, 0.9998935459556808, 0.9998947176599114], [3.5, 0.9911435650779723, 0.9911091172112608, 0.9910976200469171], [4.0, 0.9760142382363712, 0.9759761993018835, 0.9759635344084954], [4.5, 0.9710177237327016, 0.9710271946545045, 0.9710304205002571], [5.0, 0.9786153683547646, 0.9786903020286574, 0.9787153621518001], [5.5, 0.9910248933652287, 0.9911218145708728, 0.991154101586768], [6.0, 0.9990499036122267, 0.9990935156229598, 0.9991078516262206], [6.5, 0.9990820498901571, 0.9990346254408591, 0.9990185535333063], [7.0, 0.9942059475232317, 0.994112435247021, 0.9940812523895401], [7.5, 0.9902180177609442, 0.9901760150763548, 0.9901624699049509], [8.0, 0.9906574952212244, 0.9907296346566276, 0.990754353126725], [8.5, 0.9946898169024588, 0.9948373183984213, 0.9948866746639843], [9.0, 0.9987598699371236, 0.9988662991721523, 0.9989009617695886], [9.5, 0.9999577272563304, 0.9999316508535875, 0.9999215618860676], [10.0, 0.9981840810996288, 0.9980500392605319, 0.9980047287715802], [10.5, 0.995692267863989, 0.9955802588200731, 0.9955441769506107], [11.0, 0.9948662129689327, 0.9948987707787773, 0.9949122067341842], [11.5, 0.9962977912584604, 0.996472757114031, 0.9965326589959972], [12.0, 0.998624367558937, 0.9988051641374674, 0.9988638295586801], [12.5, 0.9999539951623191, 0.9999865031657512, 0.999993079400479], [13.0, 0.999482400250024, 0.9993384581643924, 0.9992872297098441], [13.5, 0.9979802436619936, 0.9977942808760766, 0.9977339546769284], [14.0, 0.996935656239911, 0.9968916160108692, 0.9968834180629981], [14.5, 0.9972429376135712, 0.9974065058459188, 0.9974670146531173], [15.0, 0.99855898237406, 0.9988081687222836, 0.9988902369976241], [15.5, 0.9997514047455108, 0.9998768161682261, 0.9999095824694846], [16.0, 0.999925957167847, 0.9998185311394587, 0.9997727399283656], [16.5, 0.9991256303014803, 0.998883361450668, 0.9988017834767636], [17.0, 0.998179834816391, 0.9980302152175398, 0.9979920341011339], [17.5, 0.9979345114125853, 0.9980336853102906, 0.9980822624554067], [18.0, 0.9985625804714882, 0.9988488081355371, 0.9989487280146335], [18.5, 0.9995015376158903, 0.999739762668164, 0.9998054117888578], [19.0, 0.9999933013031173, 0.9999796189558801, 0.9999525826249289], [19.5, 0.9997205387471491, 0.9994682975459974, 0.9993735966149765]]}, \"id\": \"el5684169326744\"});\n",
        "   }(mpld3);\n",
        "}else if(typeof define === \"function\" && define.amd){\n",
        "   // require.js is available: use it to load d3/mpld3\n",
        "   require.config({paths: {d3: \"https://mpld3.github.io/js/d3.v3.min\"}});\n",
        "   require([\"d3\"], function(d3){\n",
        "      window.d3 = d3;\n",
        "      mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "         \n",
        "         mpld3.draw_figure(\"fig_el5684169326744738489165\", {\"axes\": [{\"xlim\": [0.0, 20.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"t_max\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el5684171135720\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"overlap\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.044942876344086002, 0.5], \"rotation\": -90.0, \"id\": \"el5684171126288\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"overlap with final ground state\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el5684171199680\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"euler\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.92151797715053785, 0.96057347670250903], \"rotation\": -0.0, \"id\": \"el5684171270776\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"unitary\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.92151797715053785, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el5684171272792\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"expm\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.92151797715053785, 0.89008363201911578], \"rotation\": -0.0, \"id\": \"el5684173421232\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 20.0], \"ylim\": [0.65000000000000002, 1.0], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el5684171245408\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"color\": \"#D3D3D3\", \"alpha\": 0.7, \"dasharray\": \"2,2\", \"gridOn\": true}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 5, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"color\": \"#D3D3D3\", \"alpha\": 0.7, \"dasharray\": \"2,2\", \"gridOn\": true}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el5684171170896\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el5684169247800\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el5684171124552\"}, {\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el5684171271504\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el5684171273576\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el5684173422016\"}], \"markers\": [], \"id\": \"el5684169249088\", \"ydomain\": [0.65000000000000002, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data02\": [[0.8767151097670253, 0.968936678614098, 0.9336917562724016, 0.8984468339307048], [0.9018047155017923, 0.968936678614098, 0.9336917562724016, 0.8984468339307048]], \"data03\": [[0.8641703068996417, 0.8751493428912785], [0.9910394265232977, 0.8751493428912785], [0.9910394265232977, 0.9880525686977301], [0.8641703068996417, 0.9880525686977301], [0.8641703068996417, 0.8751493428912785]], \"data01\": [[1.0, 0.6516182770347534, 0.6516249557032787, 0.6516271820780914], [1.5, 0.7879887868989918, 0.788011854466613, 0.7880195445853719], [2.0, 0.9061899948626114, 0.9062297889384199, 0.9062430550621546], [2.5, 0.9776795613587497, 0.9777155361441456, 0.9777275251036297], [3.0, 0.99988999298591, 0.9998935459556808, 0.9998947176599114], [3.5, 0.9911435650779723, 0.9911091172112608, 0.9910976200469171], [4.0, 0.9760142382363712, 0.9759761993018835, 0.9759635344084954], [4.5, 0.9710177237327016, 0.9710271946545045, 0.9710304205002571], [5.0, 0.9786153683547646, 0.9786903020286574, 0.9787153621518001], [5.5, 0.9910248933652287, 0.9911218145708728, 0.991154101586768], [6.0, 0.9990499036122267, 0.9990935156229598, 0.9991078516262206], [6.5, 0.9990820498901571, 0.9990346254408591, 0.9990185535333063], [7.0, 0.9942059475232317, 0.994112435247021, 0.9940812523895401], [7.5, 0.9902180177609442, 0.9901760150763548, 0.9901624699049509], [8.0, 0.9906574952212244, 0.9907296346566276, 0.990754353126725], [8.5, 0.9946898169024588, 0.9948373183984213, 0.9948866746639843], [9.0, 0.9987598699371236, 0.9988662991721523, 0.9989009617695886], [9.5, 0.9999577272563304, 0.9999316508535875, 0.9999215618860676], [10.0, 0.9981840810996288, 0.9980500392605319, 0.9980047287715802], [10.5, 0.995692267863989, 0.9955802588200731, 0.9955441769506107], [11.0, 0.9948662129689327, 0.9948987707787773, 0.9949122067341842], [11.5, 0.9962977912584604, 0.996472757114031, 0.9965326589959972], [12.0, 0.998624367558937, 0.9988051641374674, 0.9988638295586801], [12.5, 0.9999539951623191, 0.9999865031657512, 0.999993079400479], [13.0, 0.999482400250024, 0.9993384581643924, 0.9992872297098441], [13.5, 0.9979802436619936, 0.9977942808760766, 0.9977339546769284], [14.0, 0.996935656239911, 0.9968916160108692, 0.9968834180629981], [14.5, 0.9972429376135712, 0.9974065058459188, 0.9974670146531173], [15.0, 0.99855898237406, 0.9988081687222836, 0.9988902369976241], [15.5, 0.9997514047455108, 0.9998768161682261, 0.9999095824694846], [16.0, 0.999925957167847, 0.9998185311394587, 0.9997727399283656], [16.5, 0.9991256303014803, 0.998883361450668, 0.9988017834767636], [17.0, 0.998179834816391, 0.9980302152175398, 0.9979920341011339], [17.5, 0.9979345114125853, 0.9980336853102906, 0.9980822624554067], [18.0, 0.9985625804714882, 0.9988488081355371, 0.9989487280146335], [18.5, 0.9995015376158903, 0.999739762668164, 0.9998054117888578], [19.0, 0.9999933013031173, 0.9999796189558801, 0.9999525826249289], [19.5, 0.9997205387471491, 0.9994682975459974, 0.9993735966149765]]}, \"id\": \"el5684169326744\"});\n",
        "      });\n",
        "    });\n",
        "}else{\n",
        "    // require.js not available: dynamically load d3 & mpld3\n",
        "    mpld3_load_lib(\"https://mpld3.github.io/js/d3.v3.min.js\", function(){\n",
        "         mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "                 \n",
        "                 mpld3.draw_figure(\"fig_el5684169326744738489165\", {\"axes\": [{\"xlim\": [0.0, 20.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"t_max\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el5684171135720\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"overlap\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.044942876344086002, 0.5], \"rotation\": -90.0, \"id\": \"el5684171126288\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"overlap with final ground state\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el5684171199680\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"euler\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.92151797715053785, 0.96057347670250903], \"rotation\": -0.0, \"id\": \"el5684171270776\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"unitary\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.92151797715053785, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el5684171272792\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"expm\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.92151797715053785, 0.89008363201911578], \"rotation\": -0.0, \"id\": \"el5684173421232\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 20.0], \"ylim\": [0.65000000000000002, 1.0], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el5684171245408\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"color\": \"#D3D3D3\", \"alpha\": 0.7, \"dasharray\": \"2,2\", \"gridOn\": true}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 5, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"color\": \"#D3D3D3\", \"alpha\": 0.7, \"dasharray\": \"2,2\", \"gridOn\": true}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el5684171170896\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el5684169247800\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el5684171124552\"}, {\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el5684171271504\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el5684171273576\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el5684173422016\"}], \"markers\": [], \"id\": \"el5684169249088\", \"ydomain\": [0.65000000000000002, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data02\": [[0.8767151097670253, 0.968936678614098, 0.9336917562724016, 0.8984468339307048], [0.9018047155017923, 0.968936678614098, 0.9336917562724016, 0.8984468339307048]], \"data03\": [[0.8641703068996417, 0.8751493428912785], [0.9910394265232977, 0.8751493428912785], [0.9910394265232977, 0.9880525686977301], [0.8641703068996417, 0.9880525686977301], [0.8641703068996417, 0.8751493428912785]], \"data01\": [[1.0, 0.6516182770347534, 0.6516249557032787, 0.6516271820780914], [1.5, 0.7879887868989918, 0.788011854466613, 0.7880195445853719], [2.0, 0.9061899948626114, 0.9062297889384199, 0.9062430550621546], [2.5, 0.9776795613587497, 0.9777155361441456, 0.9777275251036297], [3.0, 0.99988999298591, 0.9998935459556808, 0.9998947176599114], [3.5, 0.9911435650779723, 0.9911091172112608, 0.9910976200469171], [4.0, 0.9760142382363712, 0.9759761993018835, 0.9759635344084954], [4.5, 0.9710177237327016, 0.9710271946545045, 0.9710304205002571], [5.0, 0.9786153683547646, 0.9786903020286574, 0.9787153621518001], [5.5, 0.9910248933652287, 0.9911218145708728, 0.991154101586768], [6.0, 0.9990499036122267, 0.9990935156229598, 0.9991078516262206], [6.5, 0.9990820498901571, 0.9990346254408591, 0.9990185535333063], [7.0, 0.9942059475232317, 0.994112435247021, 0.9940812523895401], [7.5, 0.9902180177609442, 0.9901760150763548, 0.9901624699049509], [8.0, 0.9906574952212244, 0.9907296346566276, 0.990754353126725], [8.5, 0.9946898169024588, 0.9948373183984213, 0.9948866746639843], [9.0, 0.9987598699371236, 0.9988662991721523, 0.9989009617695886], [9.5, 0.9999577272563304, 0.9999316508535875, 0.9999215618860676], [10.0, 0.9981840810996288, 0.9980500392605319, 0.9980047287715802], [10.5, 0.995692267863989, 0.9955802588200731, 0.9955441769506107], [11.0, 0.9948662129689327, 0.9948987707787773, 0.9949122067341842], [11.5, 0.9962977912584604, 0.996472757114031, 0.9965326589959972], [12.0, 0.998624367558937, 0.9988051641374674, 0.9988638295586801], [12.5, 0.9999539951623191, 0.9999865031657512, 0.999993079400479], [13.0, 0.999482400250024, 0.9993384581643924, 0.9992872297098441], [13.5, 0.9979802436619936, 0.9977942808760766, 0.9977339546769284], [14.0, 0.996935656239911, 0.9968916160108692, 0.9968834180629981], [14.5, 0.9972429376135712, 0.9974065058459188, 0.9974670146531173], [15.0, 0.99855898237406, 0.9988081687222836, 0.9988902369976241], [15.5, 0.9997514047455108, 0.9998768161682261, 0.9999095824694846], [16.0, 0.999925957167847, 0.9998185311394587, 0.9997727399283656], [16.5, 0.9991256303014803, 0.998883361450668, 0.9988017834767636], [17.0, 0.998179834816391, 0.9980302152175398, 0.9979920341011339], [17.5, 0.9979345114125853, 0.9980336853102906, 0.9980822624554067], [18.0, 0.9985625804714882, 0.9988488081355371, 0.9989487280146335], [18.5, 0.9995015376158903, 0.999739762668164, 0.9998054117888578], [19.0, 0.9999933013031173, 0.9999796189558801, 0.9999525826249289], [19.5, 0.9997205387471491, 0.9994682975459974, 0.9993735966149765]]}, \"id\": \"el5684169326744\"});\n",
        "            })\n",
        "         });\n",
        "}\n",
        "</script>"
       ],
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAtkAAAIxCAYAAACYWqRxAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
       "text": [
        "<matplotlib.figure.Figure at 0xa17b898>"
       ]
      }
     ],
     "prompt_number": 7
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Time evolution of the overlaps (for different $t_{\\max}$es):"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "t_maxes = [1, 2, 5, 10]\n",
      "\n",
      "plt.title('overlap with ground state')\n",
      "plt.xlabel('s = t/t_max')\n",
      "plt.ylabel('overlap')\n",
      "plt.grid(color='lightgray', alpha=0.7)\n",
      "for t_max in t_maxes:\n",
      "    ts, overlaps = adiabatic(t_max)\n",
      "    plt.plot(ts/t_max, overlaps, label=str(t_max))\n",
      "plt.legend()\n",
      "plt.show()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "\n",
        "\n",
        "<style>\n",
        "\n",
        "</style>\n",
        "\n",
        "<div id=\"fig_el56841712421604914645462\"></div>\n",
        "<script>\n",
        "function mpld3_load_lib(url, callback){\n",
        "  var s = document.createElement('script');\n",
        "  s.src = url;\n",
        "  s.async = true;\n",
        "  s.onreadystatechange = s.onload = callback;\n",
        "  s.onerror = function(){console.warn(\"failed to load library \" + url);};\n",
        "  document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
        "}\n",
        "\n",
        "if(typeof(mpld3) !== \"undefined\" && mpld3._mpld3IsLoaded){\n",
        "   // already loaded: just create the figure\n",
        "   !function(mpld3){\n",
        "       \n",
        "       mpld3.draw_figure(\"fig_el56841712421604914645462\", {\"axes\": [{\"xlim\": [0.0, 1.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"s = t/t_max\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el5684170247952\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"overlap\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.044942876344086002, 0.5], \"rotation\": -90.0, \"id\": \"el5684173464544\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"overlap with ground state\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el5684170261248\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"1\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.96412970430107559, 0.96057347670250925], \"rotation\": -0.0, \"id\": \"el5684173543944\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"2\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.96412970430107559, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el5684173545960\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.96412970430107559, 0.890083632019116], \"rotation\": -0.0, \"id\": \"el5684171209224\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"10\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.96412970430107559, 0.85483870967741959], \"rotation\": -0.0, \"id\": \"el5684171211296\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 1.0], \"ylim\": [0.65000000000000002, 1.0], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data04\", \"id\": \"el5684173513248\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"color\": \"#D3D3D3\", \"alpha\": 0.7, \"dasharray\": \"2,2\", \"gridOn\": true}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"color\": \"#D3D3D3\", \"alpha\": 0.7, \"dasharray\": \"2,2\", \"gridOn\": true}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el5684173473408\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el5684171198840\"}, {\"color\": \"#FF0000\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el5684173497536\"}, {\"color\": \"#00BFBF\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el5684173513192\"}, {\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el5684173544840\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el5684173546688\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el5684171210008\"}, {\"color\": \"#00BFBF\", \"yindex\": 4, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el5684171212080\"}], \"markers\": [], \"id\": \"el5684171199120\", \"ydomain\": [0.65000000000000002, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data04\": [[0.9067820340501794, 0.8399044205495819], [0.9910394265232977, 0.8399044205495819], [0.9910394265232977, 0.9880525686977301], [0.9067820340501794, 0.9880525686977301], [0.9067820340501794, 0.8399044205495819]], \"data02\": [[0.0, 1.0, 1.0], [0.0101010101010101, 0.9999370638369375, 0.9999370638369377], [0.0202020202020202, 0.9997489127456384, 0.9997508308675359], [0.030303030303030304, 0.9994375120529332, 0.9994489222538424], [0.0404040404040404, 0.9990061144858371, 0.9990436929213914], [0.05050505050505051, 0.9984592261952727, 0.9985517259618829], [0.06060606060606061, 0.9978025596872082, 0.9979931540077552], [0.0707070707070707, 0.997042974152837, 0.9973908353498457], [0.0808080808080808, 0.9961884038210914, 0.9967694185136623], [0.09090909090909091, 0.9952477750818837, 0.9961543335743593], [0.10101010101010102, 0.9942309132457532, 0.9955707514885663], [0.11111111111111112, 0.9931484399138719, 0.9950425540300566], [0.12121212121212122, 0.9920116620304077, 0.9945913564822983], [0.13131313131313133, 0.9908324537761675, 0.9942356230819861], [0.1414141414141414, 0.9896231325371802, 0.993989911412015], [0.15151515151515152, 0.9883963302437924, 0.9938642766654036], [0.1616161616161616, 0.9871648614242051, 0.9938638601593204], [0.1717171717171717, 0.9859415893506849, 0.9939886789383334], [0.18181818181818182, 0.9847392916766227, 0.9942336250768986], [0.1919191919191919, 0.9835705269679179, 0.994588674709632], [0.20202020202020204, 0.9824475035228437, 0.9950392982352777], [0.2121212121212121, 0.9813819518506163, 0.9955670549076958], [0.22222222222222224, 0.9803850021406926, 0.9961503474815877], [0.23232323232323232, 0.9794670680026994, 0.9967653060307992], [0.24242424242424243, 0.9786377376913697, 0.9973867647709285], [0.2525252525252525, 0.9779056739527076, 0.9979892919119973], [0.26262626262626265, 0.9772785235375154, 0.9985482303967973], [0.2727272727272727, 0.9767628373274841, 0.9990407069350539], [0.2828282828282828, 0.9763640019081431, 0.9994465680409749], [0.29292929292929293, 0.9760861833034371, 0.9997492047689618], [0.30303030303030304, 0.9759322834596394, 0.9999362323970549], [0.3131313131313131, 0.9759039099331592, 0.9999999972436009], [0.3232323232323232, 0.9760013590988526, 0.9999378898768211], [0.33333333333333337, 0.9762236130542542, 0.9997524518998926], [0.3434343434343434, 0.9765683502520389, 0.9994512719415989], [0.35353535353535354, 0.9770319697496876, 0.9990466751089029], [0.36363636363636365, 0.977609628823024, 0.9985552186098874], [0.37373737373737376, 0.9782952935507486, 0.9979970141875514], [0.3838383838383838, 0.9790818018415972, 0.9973949050923278], [0.3939393939393939, 0.9799609382457571, 0.9967735312738454], [0.4040404040404041, 0.9809235197691091, 0.9961583210468568], [0.4141414141414141, 0.9819594917939358, 0.9955744504951073], [0.4242424242424242, 0.9830580331041382, 0.9950458131971847], [0.43434343434343436, 0.98420766891794, 0.9945940424359877], [0.4444444444444445, 0.9853963907473918, 0.9942376259056729], [0.4545454545454545, 0.9866117818326882, 0.9939911491446792], [0.46464646464646464, 0.987841146841076, 0.9938646986556431], [0.47474747474747475, 0.9890716444755882, 0.9938634491381422], [0.48484848484848486, 0.9902904216084443, 0.9939874517258462], [0.494949494949495, 0.9914847475380285, 0.9942316318939906], [0.505050505050505, 0.9926421469670679, 0.9945859971227962], [0.5151515151515151, 0.993750530312992, 0.9950360458186841], [0.5252525252525253, 0.9947983199893229, 0.9955633607591191], [0.5353535353535354, 0.995774571339022, 0.9961463627756842], [0.5454545454545454, 0.9966690869565908, 0.9967611938326245], [0.5555555555555556, 0.9974725232047803, 0.9973826933628699], [0.5656565656565656, 0.9981764878132817, 0.9979854279071982], [0.5757575757575758, 0.9987736275399502, 0.9985447319208938], [0.5858585858585859, 0.9992577049788822, 0.9990377171552403], [0.5959595959595959, 0.9996236637130615, 0.9994442093072129], [0.6060606060606061, 0.9998676811310167, 0.9997475736070821], [0.6161616161616161, 0.9999872083558019, 0.9999353955586604], [0.6262626262626262, 0.9999809968692143, 0.9999999889744051], [0.6363636363636364, 0.9998491115531599, 0.9999387105152218], [0.6464646464646464, 0.9995929300119284, 0.999754067863125], [0.6565656565656566, 0.9992151281824673, 0.999453617100031], [0.6666666666666667, 0.9987196523829599, 0.9990496534922425], [0.6767676767676767, 0.9981116780916723, 0.9985587083345493], [0.6868686868686869, 0.9973975558866408, 0.9980008724444658], [0.696969696969697, 0.9965847451108968, 0.9973989739910775], [0.7070707070707071, 0.9956817359561037, 0.9967776443039742], [0.7171717171717171, 0.9946979607785132, 0.9961623098919328], [0.7272727272727273, 0.993643695573551, 0.9955781519206884], [0.7373737373737373, 0.9925299526382051, 0.9950490757308209], [0.7474747474747475, 0.9913683655423917, 0.9945967325658881], [0.7575757575757576, 0.990171067610833, 0.9942396335443686], [0.7676767676767676, 0.9889505651847647, 0.9939923921341098], [0.7777777777777778, 0.9877196069873027, 0.9938651261292839], [0.7878787878787878, 0.9864910509570246, 0.9938630436026029], [0.7979797979797979, 0.9852777299407406, 0.9939862297767509], [0.8080808080808082, 0.9840923176483568, 0.9942296435368351], [0.8181818181818181, 0.9829471962700036, 0.9945833237265892], [0.8282828282828282, 0.9818543271382238, 0.9950327967861045], [0.8383838383838385, 0.9808251257862187, 0.9955596690494598], [0.8484848484848484, 0.9798703427072156, 0.9961423794637919], [0.8585858585858587, 0.9789999510605084, 0.9967570819265087], [0.8686868686868687, 0.9782230424970989, 0.9973786211329652], [0.8787878787878787, 0.977547732193125, 0.9979815620002818], [0.888888888888889, 0.976981074083013, 0.9985412305404411], [0.898989898989899, 0.9765289871778161, 0.9990347235873088], [0.909090909090909, 0.9761961937383465, 0.9994418460567828], [0.9191919191919192, 0.9759861699489407, 0.99974593738482], [0.9292929292929293, 0.9759011096070713, 0.9999345533232523], [0.9393939393939394, 0.9759419012081024, 0.9999999751924257], [0.9494949494949495, 0.9761081186645345, 0.9999395257506681], [0.9595959595959596, 0.9763980257566894, 0.9997556787543337], [0.9696969696969697, 0.9768085942683428, 0.9994559577249323], [0.9797979797979798, 0.9773355356178729, 0.9990526280660691], [0.98989898989899, 0.9779733456545124, 0.9985621951296115], [1.0, 0.9787153621518001, 0.9980047287715802]], \"data03\": [[0.919326836917563, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086], [0.94441644265233, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086]], \"data01\": [[0.0, 1.0, 0.9999999999999996], [0.010101010101010102, 0.9999370638369373, 0.9999370638369375], [0.020202020202020204, 0.9997482968747113, 0.9997483739135866], [0.030303030303030304, 0.9994338236668043, 0.9994342857040875], [0.04040404040404041, 0.9989938517110392, 0.9989953909212091], [0.05050505050505051, 0.9984286713126613, 0.9984325164016105], [0.06060606060606061, 0.9977386553927927, 0.9977467225481639], [0.07070707070707072, 0.9969242592423667, 0.9969393013322522], [0.08080808080808081, 0.9959860202217131, 0.9960117738598182], [0.09090909090909091, 0.9949245574059972, 0.9949658875057404], [0.10101010101010102, 0.9937405711767318, 0.9938036126219436], [0.11111111111111112, 0.9924348427596553, 0.9925271388254427], [0.12121212121212122, 0.9910082337092473, 0.991138870873305], [0.13131313131313133, 0.9894616853402627, 0.9896414241323177], [0.14141414141414144, 0.9877962181066201, 0.9880376196518786], [0.15151515151515152, 0.9860129309280804, 0.9863304788494038], [0.16161616161616163, 0.9841130004651506, 0.9845232178182611], [0.17171717171717174, 0.9820976803426954, 0.9826192412689536], [0.18181818181818182, 0.9799683003227534, 0.9806221361149579], [0.19191919191919193, 0.9777262654271333, 0.9785356647153206], [0.20202020202020204, 0.9753730550103391, 0.9763637577867235], [0.21212121212121213, 0.9729102217834531, 0.9741105069983842], [0.22222222222222224, 0.9703393907896136, 0.9717801572637308], [0.23232323232323235, 0.9676622583317729, 0.9693770987433853], [0.24242424242424243, 0.9648805908534245, 0.9669058585745123], [0.25252525252525254, 0.9619962237730653, 0.9643710923421146], [0.26262626262626265, 0.9590110602731272, 0.9617775753083492], [0.27272727272727276, 0.9559270700442155, 0.9591301934163786], [0.2828282828282829, 0.9527462879854497, 0.9564339340857143], [0.29292929292929293, 0.9494708128617831, 0.9536938768163834], [0.30303030303030304, 0.9461028059191817, 0.9509151836196265], [0.31313131313131315, 0.9426444894585788, 0.9481030892931542], [0.32323232323232326, 0.9390981453695381, 0.9452628915592737], [0.33333333333333337, 0.935466113624605, 0.9423999410844838], [0.3434343434343435, 0.9317507907353273, 0.9395196313993122], [0.3535353535353536, 0.9279546281709752, 0.9366273887374146], [0.36363636363636365, 0.9240801307409959, 0.9337286618130571], [0.37373737373737376, 0.9201298549422718, 0.9308289115562484], [0.38383838383838387, 0.9161064072722769, 0.9279336008248599], [0.393939393939394, 0.9120124425092428, 0.9250481841131141], [0.4040404040404041, 0.9078506619604579, 0.9221780972758244], [0.4141414141414142, 0.9036238116798817, 0.91932874728776], [0.42424242424242425, 0.899334680656218, 0.9165055020574069], [0.43434343434343436, 0.8949860989726689, 0.9137136803143313], [0.4444444444444445, 0.89058093593957, 0.9109585415891955], [0.4545454545454546, 0.8861220982011412, 0.9082452763052901], [0.4646464646464647, 0.8816125278176091, 0.9055789960002649], [0.4747474747474748, 0.8770552003239522, 0.9029647236964724], [0.48484848484848486, 0.8724531227665664, 0.900407384438059], [0.494949494949495, 0.8678093317191347, 0.8979117960126481], [0.5050505050505051, 0.8631268912790151, 0.8954826598750784], [0.5151515151515152, 0.858408891045467, 0.8931245522903015], [0.5252525252525253, 0.8536584440810514, 0.8908419157121287], [0.5353535353535354, 0.8488786848575492, 0.8886390504140659], [0.5454545454545455, 0.8440727671877518, 0.8865201063879957], [0.5555555555555556, 0.8392438621444925, 0.8844890755259885], [0.5656565656565657, 0.8343951559682878, 0.8825497840999466], [0.5757575757575758, 0.8295298479649714, 0.8807058855532676], [0.5858585858585859, 0.8246511483947034, 0.8789608536181005], [0.595959595959596, 0.8197622763537603, 0.8773179757711578], [0.6060606060606061, 0.8148664576504844, 0.8757803470404201], [0.6161616161616162, 0.8099669226768123, 0.8743508641743891], [0.6262626262626263, 0.8050669042767746, 0.8730322201848887], [0.6363636363636365, 0.8001696356133796, 0.8718268992736812], [0.6464646464646465, 0.7952783480352871, 0.8707371721524637], [0.6565656565656566, 0.7903962689446744, 0.8697650917650607], [0.6666666666666667, 0.7855266196677154, 0.8689124894198688], [0.6767676767676768, 0.7806726133290606, 0.8681809713398467], [0.686868686868687, 0.7758374527317305, 0.8675719156365378], [0.696969696969697, 0.7710243282438236, 0.8670864697138373], [0.7070707070707072, 0.7662364156934242, 0.8667255481063934], [0.7171717171717172, 0.7614768742731074, 0.866489830756708], [0.7272727272727273, 0.7567488444554177, 0.8663797617341881], [0.7373737373737375, 0.7520554459207044, 0.8663955483985636], [0.7474747474747475, 0.7473997754986701, 0.8665371610092365], [0.7575757575757577, 0.7427849051250016, 0.8668043327813131], [0.7676767676767677, 0.7382138798144241, 0.8671965603882008], [0.7777777777777778, 0.7336897156515185, 0.8677131049098266], [0.787878787878788, 0.7292153978006297, 0.8683529932246945], [0.797979797979798, 0.7247938785361743, 0.8691150198431572], [0.8080808080808082, 0.7204280752946511, 0.8699977491784422], [0.8181818181818182, 0.7161208687496396, 0.8709995182511651], [0.8282828282828284, 0.7118751009110533, 0.8721184398222247], [0.8383838383838385, 0.7076935732499077, 0.8733524059481896], [0.8484848484848485, 0.703579044849831, 0.8746990919524599], [0.8585858585858587, 0.6995342305865527, 0.8761559608047451], [0.8686868686868687, 0.6955617993365503, 0.877720267900588], [0.8787878787878789, 0.6916643722160576, 0.8793890662319447], [0.888888888888889, 0.687844520851579, 0.8811592119390712], [0.8989898989898991, 0.6841047656830648, 0.8830273702332609], [0.9090909090909092, 0.6804475743008551, 0.8849900216792727], [0.9191919191919192, 0.6768753598174991, 0.8870434688256189], [0.9292929292929294, 0.6733904792755186, 0.8891838431702179], [0.9393939393939394, 0.6699952320921677, 0.8914071124482866], [0.9494949494949496, 0.6666918585422172, 0.8937090882287544], [0.9595959595959597, 0.6634825382797617, 0.8960854338048705], [0.9696969696969697, 0.660369388900023, 0.8985316723641567], [0.9797979797979799, 0.6573544645421071, 0.9010431954222996], [0.98989898989899, 0.6544397545336271, 0.9036152715051055], [1.0, 0.6516271820780914, 0.9062430550621546]]}, \"id\": \"el5684171242160\"});\n",
        "   }(mpld3);\n",
        "}else if(typeof define === \"function\" && define.amd){\n",
        "   // require.js is available: use it to load d3/mpld3\n",
        "   require.config({paths: {d3: \"https://mpld3.github.io/js/d3.v3.min\"}});\n",
        "   require([\"d3\"], function(d3){\n",
        "      window.d3 = d3;\n",
        "      mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "         \n",
        "         mpld3.draw_figure(\"fig_el56841712421604914645462\", {\"axes\": [{\"xlim\": [0.0, 1.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"s = t/t_max\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el5684170247952\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"overlap\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.044942876344086002, 0.5], \"rotation\": -90.0, \"id\": \"el5684173464544\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"overlap with ground state\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el5684170261248\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"1\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.96412970430107559, 0.96057347670250925], \"rotation\": -0.0, \"id\": \"el5684173543944\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"2\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.96412970430107559, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el5684173545960\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.96412970430107559, 0.890083632019116], \"rotation\": -0.0, \"id\": \"el5684171209224\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"10\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.96412970430107559, 0.85483870967741959], \"rotation\": -0.0, \"id\": \"el5684171211296\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 1.0], \"ylim\": [0.65000000000000002, 1.0], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data04\", \"id\": \"el5684173513248\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"color\": \"#D3D3D3\", \"alpha\": 0.7, \"dasharray\": \"2,2\", \"gridOn\": true}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"color\": \"#D3D3D3\", \"alpha\": 0.7, \"dasharray\": \"2,2\", \"gridOn\": true}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el5684173473408\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el5684171198840\"}, {\"color\": \"#FF0000\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el5684173497536\"}, {\"color\": \"#00BFBF\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el5684173513192\"}, {\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el5684173544840\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el5684173546688\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el5684171210008\"}, {\"color\": \"#00BFBF\", \"yindex\": 4, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el5684171212080\"}], \"markers\": [], \"id\": \"el5684171199120\", \"ydomain\": [0.65000000000000002, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data04\": [[0.9067820340501794, 0.8399044205495819], [0.9910394265232977, 0.8399044205495819], [0.9910394265232977, 0.9880525686977301], [0.9067820340501794, 0.9880525686977301], [0.9067820340501794, 0.8399044205495819]], \"data02\": [[0.0, 1.0, 1.0], [0.0101010101010101, 0.9999370638369375, 0.9999370638369377], [0.0202020202020202, 0.9997489127456384, 0.9997508308675359], [0.030303030303030304, 0.9994375120529332, 0.9994489222538424], [0.0404040404040404, 0.9990061144858371, 0.9990436929213914], [0.05050505050505051, 0.9984592261952727, 0.9985517259618829], [0.06060606060606061, 0.9978025596872082, 0.9979931540077552], [0.0707070707070707, 0.997042974152837, 0.9973908353498457], [0.0808080808080808, 0.9961884038210914, 0.9967694185136623], [0.09090909090909091, 0.9952477750818837, 0.9961543335743593], [0.10101010101010102, 0.9942309132457532, 0.9955707514885663], [0.11111111111111112, 0.9931484399138719, 0.9950425540300566], [0.12121212121212122, 0.9920116620304077, 0.9945913564822983], [0.13131313131313133, 0.9908324537761675, 0.9942356230819861], [0.1414141414141414, 0.9896231325371802, 0.993989911412015], [0.15151515151515152, 0.9883963302437924, 0.9938642766654036], [0.1616161616161616, 0.9871648614242051, 0.9938638601593204], [0.1717171717171717, 0.9859415893506849, 0.9939886789383334], [0.18181818181818182, 0.9847392916766227, 0.9942336250768986], [0.1919191919191919, 0.9835705269679179, 0.994588674709632], [0.20202020202020204, 0.9824475035228437, 0.9950392982352777], [0.2121212121212121, 0.9813819518506163, 0.9955670549076958], [0.22222222222222224, 0.9803850021406926, 0.9961503474815877], [0.23232323232323232, 0.9794670680026994, 0.9967653060307992], [0.24242424242424243, 0.9786377376913697, 0.9973867647709285], [0.2525252525252525, 0.9779056739527076, 0.9979892919119973], [0.26262626262626265, 0.9772785235375154, 0.9985482303967973], [0.2727272727272727, 0.9767628373274841, 0.9990407069350539], [0.2828282828282828, 0.9763640019081431, 0.9994465680409749], [0.29292929292929293, 0.9760861833034371, 0.9997492047689618], [0.30303030303030304, 0.9759322834596394, 0.9999362323970549], [0.3131313131313131, 0.9759039099331592, 0.9999999972436009], [0.3232323232323232, 0.9760013590988526, 0.9999378898768211], [0.33333333333333337, 0.9762236130542542, 0.9997524518998926], [0.3434343434343434, 0.9765683502520389, 0.9994512719415989], [0.35353535353535354, 0.9770319697496876, 0.9990466751089029], [0.36363636363636365, 0.977609628823024, 0.9985552186098874], [0.37373737373737376, 0.9782952935507486, 0.9979970141875514], [0.3838383838383838, 0.9790818018415972, 0.9973949050923278], [0.3939393939393939, 0.9799609382457571, 0.9967735312738454], [0.4040404040404041, 0.9809235197691091, 0.9961583210468568], [0.4141414141414141, 0.9819594917939358, 0.9955744504951073], [0.4242424242424242, 0.9830580331041382, 0.9950458131971847], [0.43434343434343436, 0.98420766891794, 0.9945940424359877], [0.4444444444444445, 0.9853963907473918, 0.9942376259056729], [0.4545454545454545, 0.9866117818326882, 0.9939911491446792], [0.46464646464646464, 0.987841146841076, 0.9938646986556431], [0.47474747474747475, 0.9890716444755882, 0.9938634491381422], [0.48484848484848486, 0.9902904216084443, 0.9939874517258462], [0.494949494949495, 0.9914847475380285, 0.9942316318939906], [0.505050505050505, 0.9926421469670679, 0.9945859971227962], [0.5151515151515151, 0.993750530312992, 0.9950360458186841], [0.5252525252525253, 0.9947983199893229, 0.9955633607591191], [0.5353535353535354, 0.995774571339022, 0.9961463627756842], [0.5454545454545454, 0.9966690869565908, 0.9967611938326245], [0.5555555555555556, 0.9974725232047803, 0.9973826933628699], [0.5656565656565656, 0.9981764878132817, 0.9979854279071982], [0.5757575757575758, 0.9987736275399502, 0.9985447319208938], [0.5858585858585859, 0.9992577049788822, 0.9990377171552403], [0.5959595959595959, 0.9996236637130615, 0.9994442093072129], [0.6060606060606061, 0.9998676811310167, 0.9997475736070821], [0.6161616161616161, 0.9999872083558019, 0.9999353955586604], [0.6262626262626262, 0.9999809968692143, 0.9999999889744051], [0.6363636363636364, 0.9998491115531599, 0.9999387105152218], [0.6464646464646464, 0.9995929300119284, 0.999754067863125], [0.6565656565656566, 0.9992151281824673, 0.999453617100031], [0.6666666666666667, 0.9987196523829599, 0.9990496534922425], [0.6767676767676767, 0.9981116780916723, 0.9985587083345493], [0.6868686868686869, 0.9973975558866408, 0.9980008724444658], [0.696969696969697, 0.9965847451108968, 0.9973989739910775], [0.7070707070707071, 0.9956817359561037, 0.9967776443039742], [0.7171717171717171, 0.9946979607785132, 0.9961623098919328], [0.7272727272727273, 0.993643695573551, 0.9955781519206884], [0.7373737373737373, 0.9925299526382051, 0.9950490757308209], [0.7474747474747475, 0.9913683655423917, 0.9945967325658881], [0.7575757575757576, 0.990171067610833, 0.9942396335443686], [0.7676767676767676, 0.9889505651847647, 0.9939923921341098], [0.7777777777777778, 0.9877196069873027, 0.9938651261292839], [0.7878787878787878, 0.9864910509570246, 0.9938630436026029], [0.7979797979797979, 0.9852777299407406, 0.9939862297767509], [0.8080808080808082, 0.9840923176483568, 0.9942296435368351], [0.8181818181818181, 0.9829471962700036, 0.9945833237265892], [0.8282828282828282, 0.9818543271382238, 0.9950327967861045], [0.8383838383838385, 0.9808251257862187, 0.9955596690494598], [0.8484848484848484, 0.9798703427072156, 0.9961423794637919], [0.8585858585858587, 0.9789999510605084, 0.9967570819265087], [0.8686868686868687, 0.9782230424970989, 0.9973786211329652], [0.8787878787878787, 0.977547732193125, 0.9979815620002818], [0.888888888888889, 0.976981074083013, 0.9985412305404411], [0.898989898989899, 0.9765289871778161, 0.9990347235873088], [0.909090909090909, 0.9761961937383465, 0.9994418460567828], [0.9191919191919192, 0.9759861699489407, 0.99974593738482], [0.9292929292929293, 0.9759011096070713, 0.9999345533232523], [0.9393939393939394, 0.9759419012081024, 0.9999999751924257], [0.9494949494949495, 0.9761081186645345, 0.9999395257506681], [0.9595959595959596, 0.9763980257566894, 0.9997556787543337], [0.9696969696969697, 0.9768085942683428, 0.9994559577249323], [0.9797979797979798, 0.9773355356178729, 0.9990526280660691], [0.98989898989899, 0.9779733456545124, 0.9985621951296115], [1.0, 0.9787153621518001, 0.9980047287715802]], \"data03\": [[0.919326836917563, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086], [0.94441644265233, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086]], \"data01\": [[0.0, 1.0, 0.9999999999999996], [0.010101010101010102, 0.9999370638369373, 0.9999370638369375], [0.020202020202020204, 0.9997482968747113, 0.9997483739135866], [0.030303030303030304, 0.9994338236668043, 0.9994342857040875], [0.04040404040404041, 0.9989938517110392, 0.9989953909212091], [0.05050505050505051, 0.9984286713126613, 0.9984325164016105], [0.06060606060606061, 0.9977386553927927, 0.9977467225481639], [0.07070707070707072, 0.9969242592423667, 0.9969393013322522], [0.08080808080808081, 0.9959860202217131, 0.9960117738598182], [0.09090909090909091, 0.9949245574059972, 0.9949658875057404], [0.10101010101010102, 0.9937405711767318, 0.9938036126219436], [0.11111111111111112, 0.9924348427596553, 0.9925271388254427], [0.12121212121212122, 0.9910082337092473, 0.991138870873305], [0.13131313131313133, 0.9894616853402627, 0.9896414241323177], [0.14141414141414144, 0.9877962181066201, 0.9880376196518786], [0.15151515151515152, 0.9860129309280804, 0.9863304788494038], [0.16161616161616163, 0.9841130004651506, 0.9845232178182611], [0.17171717171717174, 0.9820976803426954, 0.9826192412689536], [0.18181818181818182, 0.9799683003227534, 0.9806221361149579], [0.19191919191919193, 0.9777262654271333, 0.9785356647153206], [0.20202020202020204, 0.9753730550103391, 0.9763637577867235], [0.21212121212121213, 0.9729102217834531, 0.9741105069983842], [0.22222222222222224, 0.9703393907896136, 0.9717801572637308], [0.23232323232323235, 0.9676622583317729, 0.9693770987433853], [0.24242424242424243, 0.9648805908534245, 0.9669058585745123], [0.25252525252525254, 0.9619962237730653, 0.9643710923421146], [0.26262626262626265, 0.9590110602731272, 0.9617775753083492], [0.27272727272727276, 0.9559270700442155, 0.9591301934163786], [0.2828282828282829, 0.9527462879854497, 0.9564339340857143], [0.29292929292929293, 0.9494708128617831, 0.9536938768163834], [0.30303030303030304, 0.9461028059191817, 0.9509151836196265], [0.31313131313131315, 0.9426444894585788, 0.9481030892931542], [0.32323232323232326, 0.9390981453695381, 0.9452628915592737], [0.33333333333333337, 0.935466113624605, 0.9423999410844838], [0.3434343434343435, 0.9317507907353273, 0.9395196313993122], [0.3535353535353536, 0.9279546281709752, 0.9366273887374146], [0.36363636363636365, 0.9240801307409959, 0.9337286618130571], [0.37373737373737376, 0.9201298549422718, 0.9308289115562484], [0.38383838383838387, 0.9161064072722769, 0.9279336008248599], [0.393939393939394, 0.9120124425092428, 0.9250481841131141], [0.4040404040404041, 0.9078506619604579, 0.9221780972758244], [0.4141414141414142, 0.9036238116798817, 0.91932874728776], [0.42424242424242425, 0.899334680656218, 0.9165055020574069], [0.43434343434343436, 0.8949860989726689, 0.9137136803143313], [0.4444444444444445, 0.89058093593957, 0.9109585415891955], [0.4545454545454546, 0.8861220982011412, 0.9082452763052901], [0.4646464646464647, 0.8816125278176091, 0.9055789960002649], [0.4747474747474748, 0.8770552003239522, 0.9029647236964724], [0.48484848484848486, 0.8724531227665664, 0.900407384438059], [0.494949494949495, 0.8678093317191347, 0.8979117960126481], [0.5050505050505051, 0.8631268912790151, 0.8954826598750784], [0.5151515151515152, 0.858408891045467, 0.8931245522903015], [0.5252525252525253, 0.8536584440810514, 0.8908419157121287], [0.5353535353535354, 0.8488786848575492, 0.8886390504140659], [0.5454545454545455, 0.8440727671877518, 0.8865201063879957], [0.5555555555555556, 0.8392438621444925, 0.8844890755259885], [0.5656565656565657, 0.8343951559682878, 0.8825497840999466], [0.5757575757575758, 0.8295298479649714, 0.8807058855532676], [0.5858585858585859, 0.8246511483947034, 0.8789608536181005], [0.595959595959596, 0.8197622763537603, 0.8773179757711578], [0.6060606060606061, 0.8148664576504844, 0.8757803470404201], [0.6161616161616162, 0.8099669226768123, 0.8743508641743891], [0.6262626262626263, 0.8050669042767746, 0.8730322201848887], [0.6363636363636365, 0.8001696356133796, 0.8718268992736812], [0.6464646464646465, 0.7952783480352871, 0.8707371721524637], [0.6565656565656566, 0.7903962689446744, 0.8697650917650607], [0.6666666666666667, 0.7855266196677154, 0.8689124894198688], [0.6767676767676768, 0.7806726133290606, 0.8681809713398467], [0.686868686868687, 0.7758374527317305, 0.8675719156365378], [0.696969696969697, 0.7710243282438236, 0.8670864697138373], [0.7070707070707072, 0.7662364156934242, 0.8667255481063934], [0.7171717171717172, 0.7614768742731074, 0.866489830756708], [0.7272727272727273, 0.7567488444554177, 0.8663797617341881], [0.7373737373737375, 0.7520554459207044, 0.8663955483985636], [0.7474747474747475, 0.7473997754986701, 0.8665371610092365], [0.7575757575757577, 0.7427849051250016, 0.8668043327813131], [0.7676767676767677, 0.7382138798144241, 0.8671965603882008], [0.7777777777777778, 0.7336897156515185, 0.8677131049098266], [0.787878787878788, 0.7292153978006297, 0.8683529932246945], [0.797979797979798, 0.7247938785361743, 0.8691150198431572], [0.8080808080808082, 0.7204280752946511, 0.8699977491784422], [0.8181818181818182, 0.7161208687496396, 0.8709995182511651], [0.8282828282828284, 0.7118751009110533, 0.8721184398222247], [0.8383838383838385, 0.7076935732499077, 0.8733524059481896], [0.8484848484848485, 0.703579044849831, 0.8746990919524599], [0.8585858585858587, 0.6995342305865527, 0.8761559608047451], [0.8686868686868687, 0.6955617993365503, 0.877720267900588], [0.8787878787878789, 0.6916643722160576, 0.8793890662319447], [0.888888888888889, 0.687844520851579, 0.8811592119390712], [0.8989898989898991, 0.6841047656830648, 0.8830273702332609], [0.9090909090909092, 0.6804475743008551, 0.8849900216792727], [0.9191919191919192, 0.6768753598174991, 0.8870434688256189], [0.9292929292929294, 0.6733904792755186, 0.8891838431702179], [0.9393939393939394, 0.6699952320921677, 0.8914071124482866], [0.9494949494949496, 0.6666918585422172, 0.8937090882287544], [0.9595959595959597, 0.6634825382797617, 0.8960854338048705], [0.9696969696969697, 0.660369388900023, 0.8985316723641567], [0.9797979797979799, 0.6573544645421071, 0.9010431954222996], [0.98989898989899, 0.6544397545336271, 0.9036152715051055], [1.0, 0.6516271820780914, 0.9062430550621546]]}, \"id\": \"el5684171242160\"});\n",
        "      });\n",
        "    });\n",
        "}else{\n",
        "    // require.js not available: dynamically load d3 & mpld3\n",
        "    mpld3_load_lib(\"https://mpld3.github.io/js/d3.v3.min.js\", function(){\n",
        "         mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "                 \n",
        "                 mpld3.draw_figure(\"fig_el56841712421604914645462\", {\"axes\": [{\"xlim\": [0.0, 1.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"s = t/t_max\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el5684170247952\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"overlap\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.044942876344086002, 0.5], \"rotation\": -90.0, \"id\": \"el5684173464544\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"overlap with ground state\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el5684170261248\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"1\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.96412970430107559, 0.96057347670250925], \"rotation\": -0.0, \"id\": \"el5684173543944\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"2\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.96412970430107559, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el5684173545960\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.96412970430107559, 0.890083632019116], \"rotation\": -0.0, \"id\": \"el5684171209224\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"10\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.96412970430107559, 0.85483870967741959], \"rotation\": -0.0, \"id\": \"el5684171211296\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 1.0], \"ylim\": [0.65000000000000002, 1.0], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data04\", \"id\": \"el5684173513248\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"color\": \"#D3D3D3\", \"alpha\": 0.7, \"dasharray\": \"2,2\", \"gridOn\": true}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"color\": \"#D3D3D3\", \"alpha\": 0.7, \"dasharray\": \"2,2\", \"gridOn\": true}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 8, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el5684173473408\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el5684171198840\"}, {\"color\": \"#FF0000\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el5684173497536\"}, {\"color\": \"#00BFBF\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el5684173513192\"}, {\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el5684173544840\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el5684173546688\"}, {\"color\": \"#FF0000\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el5684171210008\"}, {\"color\": \"#00BFBF\", \"yindex\": 4, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el5684171212080\"}], \"markers\": [], \"id\": \"el5684171199120\", \"ydomain\": [0.65000000000000002, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data04\": [[0.9067820340501794, 0.8399044205495819], [0.9910394265232977, 0.8399044205495819], [0.9910394265232977, 0.9880525686977301], [0.9067820340501794, 0.9880525686977301], [0.9067820340501794, 0.8399044205495819]], \"data02\": [[0.0, 1.0, 1.0], [0.0101010101010101, 0.9999370638369375, 0.9999370638369377], [0.0202020202020202, 0.9997489127456384, 0.9997508308675359], [0.030303030303030304, 0.9994375120529332, 0.9994489222538424], [0.0404040404040404, 0.9990061144858371, 0.9990436929213914], [0.05050505050505051, 0.9984592261952727, 0.9985517259618829], [0.06060606060606061, 0.9978025596872082, 0.9979931540077552], [0.0707070707070707, 0.997042974152837, 0.9973908353498457], [0.0808080808080808, 0.9961884038210914, 0.9967694185136623], [0.09090909090909091, 0.9952477750818837, 0.9961543335743593], [0.10101010101010102, 0.9942309132457532, 0.9955707514885663], [0.11111111111111112, 0.9931484399138719, 0.9950425540300566], [0.12121212121212122, 0.9920116620304077, 0.9945913564822983], [0.13131313131313133, 0.9908324537761675, 0.9942356230819861], [0.1414141414141414, 0.9896231325371802, 0.993989911412015], [0.15151515151515152, 0.9883963302437924, 0.9938642766654036], [0.1616161616161616, 0.9871648614242051, 0.9938638601593204], [0.1717171717171717, 0.9859415893506849, 0.9939886789383334], [0.18181818181818182, 0.9847392916766227, 0.9942336250768986], [0.1919191919191919, 0.9835705269679179, 0.994588674709632], [0.20202020202020204, 0.9824475035228437, 0.9950392982352777], [0.2121212121212121, 0.9813819518506163, 0.9955670549076958], [0.22222222222222224, 0.9803850021406926, 0.9961503474815877], [0.23232323232323232, 0.9794670680026994, 0.9967653060307992], [0.24242424242424243, 0.9786377376913697, 0.9973867647709285], [0.2525252525252525, 0.9779056739527076, 0.9979892919119973], [0.26262626262626265, 0.9772785235375154, 0.9985482303967973], [0.2727272727272727, 0.9767628373274841, 0.9990407069350539], [0.2828282828282828, 0.9763640019081431, 0.9994465680409749], [0.29292929292929293, 0.9760861833034371, 0.9997492047689618], [0.30303030303030304, 0.9759322834596394, 0.9999362323970549], [0.3131313131313131, 0.9759039099331592, 0.9999999972436009], [0.3232323232323232, 0.9760013590988526, 0.9999378898768211], [0.33333333333333337, 0.9762236130542542, 0.9997524518998926], [0.3434343434343434, 0.9765683502520389, 0.9994512719415989], [0.35353535353535354, 0.9770319697496876, 0.9990466751089029], [0.36363636363636365, 0.977609628823024, 0.9985552186098874], [0.37373737373737376, 0.9782952935507486, 0.9979970141875514], [0.3838383838383838, 0.9790818018415972, 0.9973949050923278], [0.3939393939393939, 0.9799609382457571, 0.9967735312738454], [0.4040404040404041, 0.9809235197691091, 0.9961583210468568], [0.4141414141414141, 0.9819594917939358, 0.9955744504951073], [0.4242424242424242, 0.9830580331041382, 0.9950458131971847], [0.43434343434343436, 0.98420766891794, 0.9945940424359877], [0.4444444444444445, 0.9853963907473918, 0.9942376259056729], [0.4545454545454545, 0.9866117818326882, 0.9939911491446792], [0.46464646464646464, 0.987841146841076, 0.9938646986556431], [0.47474747474747475, 0.9890716444755882, 0.9938634491381422], [0.48484848484848486, 0.9902904216084443, 0.9939874517258462], [0.494949494949495, 0.9914847475380285, 0.9942316318939906], [0.505050505050505, 0.9926421469670679, 0.9945859971227962], [0.5151515151515151, 0.993750530312992, 0.9950360458186841], [0.5252525252525253, 0.9947983199893229, 0.9955633607591191], [0.5353535353535354, 0.995774571339022, 0.9961463627756842], [0.5454545454545454, 0.9966690869565908, 0.9967611938326245], [0.5555555555555556, 0.9974725232047803, 0.9973826933628699], [0.5656565656565656, 0.9981764878132817, 0.9979854279071982], [0.5757575757575758, 0.9987736275399502, 0.9985447319208938], [0.5858585858585859, 0.9992577049788822, 0.9990377171552403], [0.5959595959595959, 0.9996236637130615, 0.9994442093072129], [0.6060606060606061, 0.9998676811310167, 0.9997475736070821], [0.6161616161616161, 0.9999872083558019, 0.9999353955586604], [0.6262626262626262, 0.9999809968692143, 0.9999999889744051], [0.6363636363636364, 0.9998491115531599, 0.9999387105152218], [0.6464646464646464, 0.9995929300119284, 0.999754067863125], [0.6565656565656566, 0.9992151281824673, 0.999453617100031], [0.6666666666666667, 0.9987196523829599, 0.9990496534922425], [0.6767676767676767, 0.9981116780916723, 0.9985587083345493], [0.6868686868686869, 0.9973975558866408, 0.9980008724444658], [0.696969696969697, 0.9965847451108968, 0.9973989739910775], [0.7070707070707071, 0.9956817359561037, 0.9967776443039742], [0.7171717171717171, 0.9946979607785132, 0.9961623098919328], [0.7272727272727273, 0.993643695573551, 0.9955781519206884], [0.7373737373737373, 0.9925299526382051, 0.9950490757308209], [0.7474747474747475, 0.9913683655423917, 0.9945967325658881], [0.7575757575757576, 0.990171067610833, 0.9942396335443686], [0.7676767676767676, 0.9889505651847647, 0.9939923921341098], [0.7777777777777778, 0.9877196069873027, 0.9938651261292839], [0.7878787878787878, 0.9864910509570246, 0.9938630436026029], [0.7979797979797979, 0.9852777299407406, 0.9939862297767509], [0.8080808080808082, 0.9840923176483568, 0.9942296435368351], [0.8181818181818181, 0.9829471962700036, 0.9945833237265892], [0.8282828282828282, 0.9818543271382238, 0.9950327967861045], [0.8383838383838385, 0.9808251257862187, 0.9955596690494598], [0.8484848484848484, 0.9798703427072156, 0.9961423794637919], [0.8585858585858587, 0.9789999510605084, 0.9967570819265087], [0.8686868686868687, 0.9782230424970989, 0.9973786211329652], [0.8787878787878787, 0.977547732193125, 0.9979815620002818], [0.888888888888889, 0.976981074083013, 0.9985412305404411], [0.898989898989899, 0.9765289871778161, 0.9990347235873088], [0.909090909090909, 0.9761961937383465, 0.9994418460567828], [0.9191919191919192, 0.9759861699489407, 0.99974593738482], [0.9292929292929293, 0.9759011096070713, 0.9999345533232523], [0.9393939393939394, 0.9759419012081024, 0.9999999751924257], [0.9494949494949495, 0.9761081186645345, 0.9999395257506681], [0.9595959595959596, 0.9763980257566894, 0.9997556787543337], [0.9696969696969697, 0.9768085942683428, 0.9994559577249323], [0.9797979797979798, 0.9773355356178729, 0.9990526280660691], [0.98989898989899, 0.9779733456545124, 0.9985621951296115], [1.0, 0.9787153621518001, 0.9980047287715802]], \"data03\": [[0.919326836917563, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086], [0.94441644265233, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086]], \"data01\": [[0.0, 1.0, 0.9999999999999996], [0.010101010101010102, 0.9999370638369373, 0.9999370638369375], [0.020202020202020204, 0.9997482968747113, 0.9997483739135866], [0.030303030303030304, 0.9994338236668043, 0.9994342857040875], [0.04040404040404041, 0.9989938517110392, 0.9989953909212091], [0.05050505050505051, 0.9984286713126613, 0.9984325164016105], [0.06060606060606061, 0.9977386553927927, 0.9977467225481639], [0.07070707070707072, 0.9969242592423667, 0.9969393013322522], [0.08080808080808081, 0.9959860202217131, 0.9960117738598182], [0.09090909090909091, 0.9949245574059972, 0.9949658875057404], [0.10101010101010102, 0.9937405711767318, 0.9938036126219436], [0.11111111111111112, 0.9924348427596553, 0.9925271388254427], [0.12121212121212122, 0.9910082337092473, 0.991138870873305], [0.13131313131313133, 0.9894616853402627, 0.9896414241323177], [0.14141414141414144, 0.9877962181066201, 0.9880376196518786], [0.15151515151515152, 0.9860129309280804, 0.9863304788494038], [0.16161616161616163, 0.9841130004651506, 0.9845232178182611], [0.17171717171717174, 0.9820976803426954, 0.9826192412689536], [0.18181818181818182, 0.9799683003227534, 0.9806221361149579], [0.19191919191919193, 0.9777262654271333, 0.9785356647153206], [0.20202020202020204, 0.9753730550103391, 0.9763637577867235], [0.21212121212121213, 0.9729102217834531, 0.9741105069983842], [0.22222222222222224, 0.9703393907896136, 0.9717801572637308], [0.23232323232323235, 0.9676622583317729, 0.9693770987433853], [0.24242424242424243, 0.9648805908534245, 0.9669058585745123], [0.25252525252525254, 0.9619962237730653, 0.9643710923421146], [0.26262626262626265, 0.9590110602731272, 0.9617775753083492], [0.27272727272727276, 0.9559270700442155, 0.9591301934163786], [0.2828282828282829, 0.9527462879854497, 0.9564339340857143], [0.29292929292929293, 0.9494708128617831, 0.9536938768163834], [0.30303030303030304, 0.9461028059191817, 0.9509151836196265], [0.31313131313131315, 0.9426444894585788, 0.9481030892931542], [0.32323232323232326, 0.9390981453695381, 0.9452628915592737], [0.33333333333333337, 0.935466113624605, 0.9423999410844838], [0.3434343434343435, 0.9317507907353273, 0.9395196313993122], [0.3535353535353536, 0.9279546281709752, 0.9366273887374146], [0.36363636363636365, 0.9240801307409959, 0.9337286618130571], [0.37373737373737376, 0.9201298549422718, 0.9308289115562484], [0.38383838383838387, 0.9161064072722769, 0.9279336008248599], [0.393939393939394, 0.9120124425092428, 0.9250481841131141], [0.4040404040404041, 0.9078506619604579, 0.9221780972758244], [0.4141414141414142, 0.9036238116798817, 0.91932874728776], [0.42424242424242425, 0.899334680656218, 0.9165055020574069], [0.43434343434343436, 0.8949860989726689, 0.9137136803143313], [0.4444444444444445, 0.89058093593957, 0.9109585415891955], [0.4545454545454546, 0.8861220982011412, 0.9082452763052901], [0.4646464646464647, 0.8816125278176091, 0.9055789960002649], [0.4747474747474748, 0.8770552003239522, 0.9029647236964724], [0.48484848484848486, 0.8724531227665664, 0.900407384438059], [0.494949494949495, 0.8678093317191347, 0.8979117960126481], [0.5050505050505051, 0.8631268912790151, 0.8954826598750784], [0.5151515151515152, 0.858408891045467, 0.8931245522903015], [0.5252525252525253, 0.8536584440810514, 0.8908419157121287], [0.5353535353535354, 0.8488786848575492, 0.8886390504140659], [0.5454545454545455, 0.8440727671877518, 0.8865201063879957], [0.5555555555555556, 0.8392438621444925, 0.8844890755259885], [0.5656565656565657, 0.8343951559682878, 0.8825497840999466], [0.5757575757575758, 0.8295298479649714, 0.8807058855532676], [0.5858585858585859, 0.8246511483947034, 0.8789608536181005], [0.595959595959596, 0.8197622763537603, 0.8773179757711578], [0.6060606060606061, 0.8148664576504844, 0.8757803470404201], [0.6161616161616162, 0.8099669226768123, 0.8743508641743891], [0.6262626262626263, 0.8050669042767746, 0.8730322201848887], [0.6363636363636365, 0.8001696356133796, 0.8718268992736812], [0.6464646464646465, 0.7952783480352871, 0.8707371721524637], [0.6565656565656566, 0.7903962689446744, 0.8697650917650607], [0.6666666666666667, 0.7855266196677154, 0.8689124894198688], [0.6767676767676768, 0.7806726133290606, 0.8681809713398467], [0.686868686868687, 0.7758374527317305, 0.8675719156365378], [0.696969696969697, 0.7710243282438236, 0.8670864697138373], [0.7070707070707072, 0.7662364156934242, 0.8667255481063934], [0.7171717171717172, 0.7614768742731074, 0.866489830756708], [0.7272727272727273, 0.7567488444554177, 0.8663797617341881], [0.7373737373737375, 0.7520554459207044, 0.8663955483985636], [0.7474747474747475, 0.7473997754986701, 0.8665371610092365], [0.7575757575757577, 0.7427849051250016, 0.8668043327813131], [0.7676767676767677, 0.7382138798144241, 0.8671965603882008], [0.7777777777777778, 0.7336897156515185, 0.8677131049098266], [0.787878787878788, 0.7292153978006297, 0.8683529932246945], [0.797979797979798, 0.7247938785361743, 0.8691150198431572], [0.8080808080808082, 0.7204280752946511, 0.8699977491784422], [0.8181818181818182, 0.7161208687496396, 0.8709995182511651], [0.8282828282828284, 0.7118751009110533, 0.8721184398222247], [0.8383838383838385, 0.7076935732499077, 0.8733524059481896], [0.8484848484848485, 0.703579044849831, 0.8746990919524599], [0.8585858585858587, 0.6995342305865527, 0.8761559608047451], [0.8686868686868687, 0.6955617993365503, 0.877720267900588], [0.8787878787878789, 0.6916643722160576, 0.8793890662319447], [0.888888888888889, 0.687844520851579, 0.8811592119390712], [0.8989898989898991, 0.6841047656830648, 0.8830273702332609], [0.9090909090909092, 0.6804475743008551, 0.8849900216792727], [0.9191919191919192, 0.6768753598174991, 0.8870434688256189], [0.9292929292929294, 0.6733904792755186, 0.8891838431702179], [0.9393939393939394, 0.6699952320921677, 0.8914071124482866], [0.9494949494949496, 0.6666918585422172, 0.8937090882287544], [0.9595959595959597, 0.6634825382797617, 0.8960854338048705], [0.9696969696969697, 0.660369388900023, 0.8985316723641567], [0.9797979797979799, 0.6573544645421071, 0.9010431954222996], [0.98989898989899, 0.6544397545336271, 0.9036152715051055], [1.0, 0.6516271820780914, 0.9062430550621546]]}, \"id\": \"el5684171242160\"});\n",
        "            })\n",
        "         });\n",
        "}\n",
        "</script>"
       ],
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAtsAAAIxCAYAAACcr3RMAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nAADgJv8fjn6Ow5VAPaoAAAAASUVORK5CYII=\n",
       "text": [
        "<matplotlib.figure.Figure at 0xa34f2b0>"
       ]
      }
     ],
     "prompt_number": 8
    }
   ],
   "metadata": {}
  }
 ]
}